=begin
/****************************************************************************
** $Id: richtext.rb,v 1.1.1.1 2002/12/22 14:19:55 taka-hr Exp $
**
** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
**
** This file is part of an example program for Qt.  This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/
=end
#include "richtext.h"
#include <qapplication.h>
require "qte"
include Qte
require "qpe"
include Qpe
require "richtext_lib.rb"

    a = QPEApplication.new ( [$0]+ARGV )

    richtext = MyRichText.new
    richtext.resize( 450, 350 )
    richtext.setCaption( "Fortune" )
    a.showMainWidget( richtext )

    a.exec()
